import * as _nuxt_schema from '@nuxt/schema';

interface ModuleOptions {
    /**
     * Whether the module is enabled at all
     */
    isEnabled: boolean;
    /**
     * Full url at which the app will run and path to authentication.
     *
     * Can be `undefined` during development but _must_ be set for production. This is the origin-part of the NEXTAUTH_URL. The origin consists out of:
     * - `scheme`: http / https
     * - `host`: e.g., localhost, example.org, google.com
     * - `port`: _empty_ (implies `:80`), :3000, :8888
     *
     * See https://next-auth.js.org/configuration/options#nextauth_url for more on this. Note that nextauth uses the full url as one.
     *
     * @example undefined
     * @example http://localhost:3000
     * @example https://example.org
     * @default http://localhost:3000
     */
    origin: string | undefined;
    /**
     * The path to the endpoint that you've added `NuxtAuth` at via `export default NuxtAuthHandler({ ... })`. See the getting started for more: https://github.com/sidebase/nuxt-auth#quick-start
     *
     * @default /api/auth
     */
    basePath: string | undefined;
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

export { _default as default };
