import type { Session } from 'next-auth';
import type { AppProvider, BuiltInProviderType } from 'next-auth/providers';
import { Ref } from 'vue';
interface UseSessionOptions {
    required?: boolean;
    callbackUrl?: string;
    onUnauthenticated?: () => void;
}
/**
 * Utility type that allows autocompletion for a mix of literal, primitiva and non-primitive values.
 * @source https://github.com/microsoft/TypeScript/issues/29729#issuecomment-832522611
 */
type LiteralUnion<T extends U, U = string> = T | (U & Record<never, never>);
type SupportedProviders = LiteralUnion<BuiltInProviderType>;
type GetSessionOptions = Partial<UseSessionOptions>;
interface SignInOptions extends Record<string, unknown> {
    /**
     * Specify to which URL the user will be redirected after signing in. Defaults to the page URL the sign-in is initiated from.
     *
     * [Documentation](https://next-auth.js.org/getting-started/client#specifying-a-callbackurl)
     */
    callbackUrl?: string;
    /** [Documentation](https://next-auth.js.org/getting-started/client#using-the-redirect-false-option) */
    redirect?: boolean;
}
type SignInAuthorizationParams = Record<string, string>;
interface SignOutOptions {
    callbackUrl?: string;
    redirect?: boolean;
}
type SessionStatus = 'authenticated' | 'unauthenticated' | 'loading';
type SessionData = Session | undefined | null;
declare const _default: (initialGetSessionOptions?: UseSessionOptions) => Promise<{
    status: Ref<SessionStatus>;
    data: Ref<SessionData>;
    getSession: (getSessionOptions?: GetSessionOptions) => Promise<any>;
    getCsrfToken: () => Promise<{
        csrfToken: string;
    }>;
    getProviders: () => Promise<Record<SupportedProviders, Omit<AppProvider, "options"> | undefined>>;
    signIn: (provider?: SupportedProviders, options?: SignInOptions, authorizationParams?: SignInAuthorizationParams) => Promise<any>;
    signOut: (options?: SignOutOptions) => Promise<any>;
}>;
export default _default;
